# tesla-web

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Jafar Idris.

## Examples of How To Use (Buggy Alpha Version)

Creating a project

```cmd
tesla startproject
```

it will prompt you to enter your project name, a folder will be created with that name navigate to the project folder.

Start server

```cmd
tesla serve [port]
```
port = 8000 by default

open your browser and navigate to the address display on your command line, you will see a 404 page because no route is specified

Creating an Application

```cmd
tesla startapp
```

it will prompt you to enter your Application name, a folder will be created with that name navigate to the Application folder.
